# Test Coverage Report: excluded packages and modules

Generated: Fri 2015-05-29 13:58 AST

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- countries
- django.contrib.admin
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- forex
- people.admin
- people.migrations
- people.settings
- people.tests

Back to index.